==> yield_analysis_sdk-0.1.1.tar.gz: yield_analysis_sdk-0.1.1/examples/analysis_service.py <==
import datetime
import json
import threading
from typing import Any, Dict, Optional

from dotenv import load_dotenv
from pydantic import BaseModel, Field, ValidationError
from virtuals_acp import ACPJob, ACPJobPhase, ACPMemo, VirtualsACP

load_dotenv(override=True)

from virtuals_acp.env import EnvSettings

from yield_analysis_sdk import (
    normalize_address,
)
from yield_analysis_sdk.analysis import analyze_yield_with_daily_share_price
from yield_analysis_sdk.subgraph import get_daily_share_price_history_from_subgraph
from yield_analysis_sdk.type import (
    AnalysisRequest,
    AnalysisResponse,
    Chain,
    SharePriceHistory,
    VaultInfo,
    VaultPerformanceAnalysis,
)


class CustomEnvSettings(EnvSettings):
    SUBGRAPH_API_KEY: Optional[str] = None


USDC_TOKEN_ADDRESS = {
    Chain.BASE: "0x833589fcd6edb6e08f4c7c32d4f71b54bda02913",
}

USDC_VAULT_ADDRESSES = {
    Chain.BASE: [
        "0xc1256Ae5FF1cf2719D4937adb3bbCCab2E00A2Ca",
        "0x616a4E1db48e22028f6bbf20444Cd3b8e3273738",
    ]
}


def seller():
    env = CustomEnvSettings()

    def on_new_task(job: ACPJob):
        # Convert job.phase to ACPJobPhase enum if it's an integer
        if job.phase == ACPJobPhase.REQUEST:
            # Check if there's a memo that indicates next phase is NEGOTIATION
            for memo in job.memos:
                if memo.next_phase == ACPJobPhase.NEGOTIATION:
                    try:
                        AnalysisRequest.model_validate_json(memo.content)
                        job.respond(True)
                    except ValidationError as e:
                        job.respond(False, "Invalid request format")
                    finally:
                        break
        elif job.phase == ACPJobPhase.TRANSACTION:

            for memo in job.memos:
                if memo.next_phase == ACPJobPhase.EVALUATION:
                    # Check if there's a memo that indicates next phase is EVALUATION
                    analysis_request = AnalysisRequest.model_validate_json(
                        job.service_requirement
                    )

                    if analysis_request.chain != Chain.BASE:
                        return

                    if analysis_request.underlying_token != normalize_address(
                        USDC_TOKEN_ADDRESS[analysis_request.chain]
                    ):
                        return

                    # fetch price history
                    price_histories = get_daily_share_price_history_from_subgraph(
                        analysis_request.chain,
                        USDC_VAULT_ADDRESSES[analysis_request.chain],
                        90,
                        env.SUBGRAPH_API_KEY,
                    )

                    # analyze yield
                    result: AnalysisResponse = AnalysisResponse(analyses=[])
                    for price_history in price_histories:
                        result.analyses.append(
                            VaultPerformanceAnalysis(
                                vault_info=VaultInfo(
                                    chain=analysis_request.chain,
                                    vault_address=price_history.vault_address,
                                    vault_name=price_history.vault_name,
                                    last_updated=datetime.now(),
                                ),
                                performance=analyze_yield_with_daily_share_price(
                                    price_history,
                                ),
                            )
                        )

                    print(f"Delivering analysis result: {result.model_dump_json()}")
                    delivery_data = {"type": "object", "value": result.model_dump()}

                    # deliver job
                    job.deliver(json.dumps(delivery_data))
                    break

    if env.WHITELISTED_WALLET_PRIVATE_KEY is None:
        raise ValueError("WHITELISTED_WALLET_PRIVATE_KEY is not set")
    if env.SELLER_ENTITY_ID is None:
        raise ValueError("SELLER_ENTITY_ID is not set")

    # Initialize the ACP client
    VirtualsACP(
        wallet_private_key=env.WHITELISTED_WALLET_PRIVATE_KEY,
        agent_wallet_address=env.SELLER_AGENT_WALLET_ADDRESS,
        on_new_task=on_new_task,
        entity_id=env.SELLER_ENTITY_ID,
    )

    print("Waiting for new task...")
    # Keep the script running to listen for new tasks
    threading.Event().wait()


if __name__ == "__main__":
    seller()

==> yield_analysis_sdk-0.2.0.tar.gz: yield_analysis_sdk-0.2.0/examples/analysis_service.py <==
import datetime
import json
import threading
from typing import Any, Dict, Optional

from dotenv import load_dotenv
from pydantic import BaseModel, Field, ValidationError
from virtuals_acp import ACPJob, ACPJobPhase, ACPMemo, VirtualsACP

load_dotenv(override=True)

from virtuals_acp.env import EnvSettings

from yield_analysis_sdk import (
    normalize_address,
)
from yield_analysis_sdk.analysis import analyze_yield_with_daily_share_price
from yield_analysis_sdk.subgraph import get_daily_share_price_history_from_subgraph
from yield_analysis_sdk.type import (
    AnalysisRequest,
    AnalysisResponse,
    Chain,
    SharePriceHistory,
    VaultInfo,
    AnalysisResult,
)


class CustomEnvSettings(EnvSettings):
    SUBGRAPH_API_KEY: Optional[str] = None


USDC_TOKEN_ADDRESS = {
    Chain.BASE: "0x833589fcd6edb6e08f4c7c32d4f71b54bda02913",
}

USDC_VAULT_ADDRESSES = {
    Chain.BASE: [
        "0xc1256Ae5FF1cf2719D4937adb3bbCCab2E00A2Ca",
        "0x616a4E1db48e22028f6bbf20444Cd3b8e3273738",
    ]
}


def seller():
    env = CustomEnvSettings()

    def on_new_task(job: ACPJob):
        # Convert job.phase to ACPJobPhase enum if it's an integer
        if job.phase == ACPJobPhase.REQUEST:
            # Check if there's a memo that indicates next phase is NEGOTIATION
            for memo in job.memos:
                if memo.next_phase == ACPJobPhase.NEGOTIATION:
                    try:
                        AnalysisRequest.model_validate_json(memo.content)
                        job.respond(True)
                    except ValidationError as e:
                        job.respond(False, "Invalid request format")
                    finally:
                        break
        elif job.phase == ACPJobPhase.TRANSACTION:

            for memo in job.memos:
                if memo.next_phase == ACPJobPhase.EVALUATION:
                    # Check if there's a memo that indicates next phase is EVALUATION
                    analysis_request = AnalysisRequest.model_validate_json(
                        job.service_requirement
                    )

                    if analysis_request.chain != Chain.BASE:
                        return

                    if analysis_request.underlying_token != normalize_address(
                        USDC_TOKEN_ADDRESS[analysis_request.chain]
                    ):
                        return

                    # fetch price history
                    price_histories = get_daily_share_price_history_from_subgraph(
                        analysis_request.chain,
                        USDC_VAULT_ADDRESSES[analysis_request.chain],
                        90,
                        env.SUBGRAPH_API_KEY,
                    )

                    # analyze yield
                    result: AnalysisResponse = AnalysisResponse(analyses=[])
                    for price_history in price_histories:
                        result.analyses.append(
                            AnalysisResult(
                                vault_info=VaultInfo(
                                    chain=analysis_request.chain,
                                    vault_address=price_history.vault_address,
                                    vault_name=price_history.vault_name,
                                    protocol="Test",
                                    last_updated_timestamp=datetime.now(),
                                ),
                                performance=analyze_yield_with_daily_share_price(
                                    price_history,
                                ),
                            )
                        )

                    print(f"Delivering analysis result: {result.model_dump_json()}")
                    delivery_data = {"type": "object", "value": result.model_dump()}

                    # deliver job
                    job.deliver(json.dumps(delivery_data))
                    break

    if env.WHITELISTED_WALLET_PRIVATE_KEY is None:
        raise ValueError("WHITELISTED_WALLET_PRIVATE_KEY is not set")
    if env.SELLER_ENTITY_ID is None:
        raise ValueError("SELLER_ENTITY_ID is not set")

    # Initialize the ACP client
    VirtualsACP(
        wallet_private_key=env.WHITELISTED_WALLET_PRIVATE_KEY,
        agent_wallet_address=env.SELLER_AGENT_WALLET_ADDRESS,
        on_new_task=on_new_task,
        entity_id=env.SELLER_ENTITY_ID,
    )

    print("Waiting for new task...")
    # Keep the script running to listen for new tasks
    threading.Event().wait()


if __name__ == "__main__":
    seller()
